@@ -1,19 +1,26 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 import logging
 
+import matplotlib
+import numpy as np
+from mud.funs import map_problem, mud_problem
+from mud.util import std_from_equipment
+from mud_examples.experiments import (experiment_equipment,
+                                      experiment_measurements)
+from mud_examples.summary import extract_statistics
+
+from mud_examples.models import generate_decay_model
+from mud_examples.models import \
+    generate_temporal_measurements as generate_sensors_ode
+from mud_examples.summary import fit_log_linear_regression
+from mud_examples.plotting import plot_decay_solution
+
 _logger = logging.getLogger(__name__)
 
-from mud.funs import mud_problem, map_problem
-from mud.util import std_from_equipment
 
-from mud_examples.models import generate_spatial_measurements as generate_sensors_pde
-from mud_examples.helpers import experiment_measurements, extract_statistics, experiment_equipment
-from mud_examples.plotting import plot_decay_solution
-from mud_examples.plotting import fit_log_linear_regression
-from mud_examples.models import generate_decay_model
-from mud_examples.models import generate_temporal_measurements as generate_sensors_ode
 
-import numpy as np
-import matplotlib
 matplotlib.rcParams['mathtext.fontset'] = 'stix'
 matplotlib.rcParams['font.family'] = 'STIXGeneral'
 matplotlib.backend = 'Agg'
@@ -56,7 +63,7 @@ def main_ode(num_trials=20,
 
     for example in example_list:
         print(f"Running example: {example}")
-        if example == 'ode-mud-alt':
+        if example == 'mud-alt':
             sensors = generate_sensors_ode(measurement_hertz=200, start_time=t_min, end_time=t_max)
         else:
             sensors = generate_sensors_ode(measurement_hertz=100, start_time=t_min, end_time=t_max)
@@ -72,15 +79,16 @@ def main_ode(num_trials=20,
         lam = np.random.rand(int(1E3)).reshape(-1,1)
         qoi = model(lam)
 
-        if example == 'ode-map':
+        if example == 'map':
             def wrapper(num_obs, sd):
                 return map_problem(domain=domain, lam=lam, qoi=qoi,
                                    sd=sd, qoi_true=qoi_true, num_obs=num_obs)
-        else:
+        elif example == 'mud':
             def wrapper(num_obs, sd):
                 return mud_problem(domain=domain, lam=lam, qoi=qoi,
                                    sd=sd, qoi_true=qoi_true, num_obs=num_obs)
-
+        else:
+            raise ValueError("Unknown example type")
 
         _logger.info("Increasing Measurements Quantity Study")
         experiments, solutions = experiment_measurements(num_measurements=measurements,
@@ -90,8 +98,8 @@ def main_ode(num_trials=20,
                                                  fun=wrapper)
 
         means, variances = extract_statistics(solutions, lam_true)
-        regression_mean, slope_mean = fit_log_linear_regression(time_ratios, means)
-        regression_vars, slope_vars = fit_log_linear_regression(time_ratios, variances)
+        regression_mean, slope_mean = fit_log_linear_regression(measurements, means)
+        regression_vars, slope_vars = fit_log_linear_regression(measurements, variances)
 
         ##########
 
@@ -116,12 +124,16 @@ def main_ode(num_trials=20,
         # TO DO clean all this up
         _in = (lam, qoi, sensors, qoi_true, experiments, solutions)
         _rm = (regression_mean, slope_mean, regression_vars, slope_vars, means, variances)
-        example_name = '-'.join(example.split('-')[1:]).upper()
+        example_name = example.upper()
         res.append((example_name, _in, _rm, _re))
 
         # TODO check for existence of save directory, grab subset of measurements properly.
         plot_decay_solution(solutions, generate_decay_model, fsize=fsize,
                             end_time=t_max, lam_true=lam_true, qoi_true=qoi_true,
-                            sigma=sigma, time_vector=sensors, prefix='ode/' + example)
+                            sigma=sigma, time_vector=sensors, prefix='figures/ode/' + example)
 
     return res
+
+
+if __name__ == '__main__':
+    main_ode()
