@@ -1,25 +1,30 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 import logging
 import os
 
+import matplotlib
+import mud_examples.poisson as ps  # lazy loads fenics
+import numpy as np
+from mud.funs import map_problem, mud_problem
+from mud.util import std_from_equipment
+from mud_examples.utils import check_dir
+from mud_examples.experiments import (experiment_equipment,
+                                      experiment_measurements)
+from mud_examples.summary import extract_statistics, fit_log_linear_regression
+
 _logger = logging.getLogger(__name__)
 
 
-import numpy as np
-import matplotlib
 matplotlib.rcParams['mathtext.fontset'] = 'stix'
 matplotlib.rcParams['font.family'] = 'STIXGeneral'
 matplotlib.backend = 'Agg'
 matplotlib.rcParams['figure.figsize'] = 10,10
 matplotlib.rcParams['font.size'] = 16
 
-from mud.funs import mud_problem, map_problem
-from mud.util import std_from_equipment
 
-from mud_examples.models import generate_spatial_measurements as generate_sensors_pde
-from mud_examples.helpers import experiment_measurements, extract_statistics, experiment_equipment, check_dir
-from mud_examples.plotting import fit_log_linear_regression
 
-import mud_examples.poisson as ps  # lazy loads fenics
 
 def main_pde(num_trials=20,
              tolerances=[0.1],
@@ -58,7 +63,7 @@ def main_pde(num_trials=20,
         # in 1d this is a change in sensor location
         # in ND, change in how we partition sensors (vertical vs horizontal)
         fdir = f'pde_{input_dim}D' # expectation from make_reproducible_without_fenics
-        check_dir(fdir)
+
         # mud and mud alt have same sensors in higher dimensional examples
         # in 1d, the alternative approach is to change sensor placement, which requires
         # loading a separate file.
@@ -80,7 +85,7 @@ def main_pde(num_trials=20,
                 P.load(fname)
             except FileNotFoundError:
                 
-                try: # available data in package
+                try:  # available data in package
                     _logger.info("Trying packaged data.")
                     fname = 'data/' + fname
                     P.load(fname)
@@ -98,9 +103,8 @@ def main_pde(num_trials=20,
                     try:
                         P.load(fname)
                     except FileNotFoundError as e:
-                        raise(e)
                         _logger.critical("Exiting program")
-                        break
+                        raise(e)
 
             # plots show only one hundred sensors to avoid clutter
             if example == 'mud-alt':
@@ -160,4 +164,8 @@ def main_pde(num_trials=20,
                 P.plot_solutions(solutions, m, example=example)
 #             P.plot_solutions(solutions, 100, example=example, save=True)
 
-    return res
\ No newline at end of file
+    return res
+
+
+if __name__ == '__main__':
+    main_pde()
